<?php
namespace Teknisa\MAN\Controllers;


use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services\CustomizacaoTAAservice;
use Teknisa\MAN\Services\FileUploaderService;
use Zeedhi\Framework\Util\Functions;

class CustomizacaoTAA extends  \Teknisa\MAN\Controllers\TeknisaCrud {
    
    const dataSourceCores = 'customizacaoTAAcores';
    const dataSourceImagens = 'customizacaoTAAimagens';

	protected $dataSourceManager;
	protected $parameterBagColumns = ['NRORG'];
    protected $customizacaoTAAservice;
    protected $fileUploaderService;
    protected $environment;
    protected $utilService;
    
    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, $dataSourceManager, $customizacaoTAAservice, $fileUploaderService, $environment) {
        
        $this->crudService                  = $crudService;
        $this->parameterBag                 = $parameterBag;
        $this->entityManager                = $entityManager;
        $this->utilService                  = $utilService;
        $this->dataSourceManager            = $dataSourceManager;
        $this->fileUploaderService          = $fileUploaderService;
        $this->CustomizacaoTAAservice       = $customizacaoTAAservice;
        $this->environment                  = $environment;
    }

    public function findCores(DTO\Request\Filter $request, DTO\Response $response) {
        $sql = "SELECT CORESJSON, NRORG, '' AS blabla FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG";
        $coresPadrao = '{"DSCORPRIMARIA":2189567, "DSCORPRIMARIASUAVE":5348095,"DSCORPRIMARIAESCURA":14020,"DSCORCABECALHO":1728760,"DSCORCATEGORIAS":16777215,"DSCORFONTECATEGORIAS":2039582,"DSCORFUNDOCARRINHO":14803426, "DSCORFONTEPRECO":255}';
        
        $conn = $this->entityManager->getConnection();
        $statement = $conn->prepare($sql);
        $NRORG = $this->environment->getNrOrgTrab();
        $params = ["NRORG" => $NRORG];
        $statement->execute($params);
        $result = $statement->fetchAll();
        if(isset($result[0]['CORESJSON'])){
           $CORESJSON = [json_decode($result[0]['CORESJSON'])];
           $response->addDataSet(new DataSet(self::dataSourceImagens, $CORESJSON));
        } else {
          $CORESJSON = [json_decode($coresPadrao)];
          $response->addDataSet(new DataSet(self::dataSourceImagens, $CORESJSON));
        }
    }
    
    public function findImagens(DTO\Request\Filter $request, DTO\Response $response) {
        $sql = "SELECT JSONB64CUSTOMMEDIA, NRORG, '' AS blabla FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG";
        $conn = $this->entityManager->getConnection();
        $statement = $conn->prepare($sql);    
        $NRORG = $this->environment->getNrOrgTrab();
        $params = ["NRORG" => $NRORG];
        $statement->execute($params);
        $result = $statement->fetchAll();
        if(isset($result[0]['JSONB64CUSTOMMEDIA'])){
            $JSONB64CUSTOMMEDIA = [json_decode($result[0]['JSONB64CUSTOMMEDIA'])];
            $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
        } else {
            // $JSONB64CUSTOMMEDIA = [json_decode($statement->fetchAll()[0]['JSONB64CUSTOMMEDIA'])];
            // $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
        return false;
        }
    }
    
    public function saveCores(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    $this->dataSourceName = self::dataSourceCores;
    	    $rows = $request->getDataSet()->getRows();
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
            unset($rows[0]['__createdLocal']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsCores = array( 
    	                    'CORESJSON'     =>    $rows[0],
                            'NRORG'                  =>    $NRORG
                        );
            $this->CustomizacaoTAAservice->saveColors($paramsCores);
            $response->addDataSet(new DataSet($this->dataSourceName,array('CORESJSON'=>$paramsCores['CORESJSON'],'NRORG'=>$paramsCores['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveImagens(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    
    	    $this->dataSourceName = self::dataSourceImagens;
    	    $rows = $request->getDataSet()->getRows();
    	    
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
    	    unset($rows[0]['NRORGULTATU']);
            unset($rows[0]['CDOPERULTATU']);
            unset($rows[0]['DTULTATU']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsImagens = array( 
                'JSONB64CUSTOMMEDIA'     =>    $rows[0],
                'NRORG'                  =>    $NRORG
            );
            
            $this->CustomizacaoTAAservice->saveImages($paramsImagens);
            $response->addDataSet(new DataSet($this->dataSourceName,array('JSONB64CUSTOMMEDIA'=>$paramsImagens['JSONB64CUSTOMMEDIA'],'NRORG'=>$paramsImagens['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveConfig(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        $NRORG = isset($conditions['NRORG']) ? $conditions['NRORG'] : null;
    
        // Lista de todos os campos possíveis com valores padrão
        $fields = [
            "urlPerifericos" => "",
            "balancaport" => "",
            "boldPrice" => false,
            "mainLanguage" => [],
            "idiomaAdic_pt_br" => false,
            "idiomaAdic_en" => false,
            "idiomaAdic_es" => false,
            "comprimentoNSU" => null,
            "shouldAutoClose" => false,
            "modeEntrega" => [],
            "modeEntregaDrive" => [],
            "modeloImpressora" => "",
            "portaImpressora" => "US",
            "useAlternativeLayout" => true,
            "slimMode" => false,
            "modotap" => false,
            "modobalanca" => false,
            "isEditMode" => false,
            "exibeContinuarComprando" => false,
            "itemsList" => false,
            "hideGroupOnMax" => false,
            "enableProdBarCodeRead" => false,
            "acessibilidade" => false,
            "agruparnaimpressao" => false,
            "produtoSemfoto" => true,
            "exibApartir" => false,
            "removeConfirmImpressaoCupom" => false,
            "cardapioExpira" => false,
            "usePager" => false,
            "allowMultipleAdd" => true,
            "imprimeEspelho" => true,
            "enableSubgroups" => true,
            "permiteObsDigitada" => false,
            "fixedServiceTax" => false,
            "showMinPriceDifference" => false,
            "timeOut" => 150,
            "timeOutInModal" => 30
        ];
    
        // Preenche os campos com os valores presentes no $conditions
        foreach ($conditions as $key => $value) {
            if (array_key_exists($key, $fields)) {
                if ($value === "S") {
                    $fields[$key] = true;
                } elseif ($value === "N") {
                    $fields[$key] = false;
                } else {
                    $fields[$key] = $value;
                }
            }
        }
        
        // verificacoes adicionais
        if (isset($conditions["mainLanguageCode"]) && isset($conditions["mainLanguageName"])) {
            $fields["mainLanguage"] = [
                [
                    "name" => $conditions["mainLanguageName"],
                    "code" => $conditions["mainLanguageCode"]
                ]
            ];
        }
        
        
        // Verificações adicionais para modeEntrega e modeEntregaDrive
        if (isset($conditions["entregaDrive"]) && $conditions["entregaDrive"] === "S") {
            $fields["modeEntregaDrive"] = ["drive"];
            $fields["modeEntrega"] = [];
        } else {
            $fields["modeEntregaDrive"] = [];
            $fields["modeEntrega"] = [];
            if (isset($conditions["entregaComer"]) && $conditions["entregaComer"] === "S") {
                $fields["modeEntrega"][] = "comer";
            }
            if (isset($conditions["entregaLevar"]) && $conditions["entregaLevar"] === "S") {
                $fields["modeEntrega"][] = "levar";
            }
        }
        
        // Converte o array para JSON
        $jsonConfigString = json_encode($fields, JSON_UNESCAPED_UNICODE);
    
        // Salva o JSON no banco de dados (exemplo fictício)
        $this->CustomizacaoTAAservice->saveJsonConfig($jsonConfigString, $NRORG);
    
        $response->addDataSet(new DataSet("customizacaoTAAconfig",array('jsonConfigString'=>$jsonConfigString,'NRORG'=>$NRORG)));
    }
 
 
    public function findJsonConfig(DTO\Request\Filter $request, DTO\Response $response) {
        // Obtém os parâmetros de filtro do request
        $params = $this->utilService->getParamsAsArray($request);
    
        // Chama o serviço para buscar o JSON config
        $jsonConfig = $this->CustomizacaoTAAservice->findJsonConfig($params['NRORG']);
    
        $response->addDataSet(new DataSet('select_jsonconfig_taa', $jsonConfig));
    }
     
}
