<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class ExportacaoBalancaToledo {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

    public function find($CDFILIAL, $CDTABEPREC, $LISTA, $TODOS, $PRODINI, $PRODFIN, $IDPESAPROD, $IDTABEPRECGER = null) {
        $enableGeneralPriceTable = false;
        
        if ($IDTABEPRECGER == "%S%" || $IDTABEPRECGER == "S") {
            $enableGeneralPriceTable = true;
        }
        
        $params = array(
         	":CDFILIAL" => $CDFILIAL,
         	":CDTABEPREC" => $CDTABEPREC,
         	":LISTA" => $LISTA,
         	":TODOS" => $TODOS,
         	":PRODINI" => $PRODINI,
         	":PRODFIN" => $PRODFIN,
         	":IDPESAPROD" => $IDPESAPROD
 		); 

        if ($enableGeneralPriceTable) {
            return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TXT_BALANCA_GERAL, $params);
         } 
         
        return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TXT_BALANCA, $params);
    }
    
    public function findTabelaPrecoGeral($conditions) {
        $params = array(
            ":CDFILIAL" => $conditions['CDFILIAL'],
            ":NRORG"    => $conditions['NRORG']
        );
        
        return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TAB_PRECO_GERAL, $params);
    }
    
    public function saveInfoExtra ($rows){
        $params = array(
            ':CDINFOEXTRA'         => $rows[0]['CDINFOEXTRA'],
            ':DSINFOEXTRA'         => $rows[0]['DSINFOEXTRA'],
            ':DSOBSINFOEXTRA'      => $rows[0]['DSOBSINFOEXTRA'],
            ':NRORG'               => $rows[0]['NRORG']
 		);
 		$this->entityManager->getConnection()->executeQuery(Utilities\Query::INSERT_INFOEXTRA, $params);
    }
    
    public function updateInfoExtra ($rows){
        $params = array(
            ':CDINFOEXTRA'         => $rows[0]['CDINFOEXTRA'],
            ':DSINFOEXTRA'         => $rows[0]['DSINFOEXTRA'],
            ':DSOBSINFOEXTRA'      => $rows[0]['DSOBSINFOEXTRA'],
            ':NRORG'               => $rows[0]['NRORG']
 		);
 		
 		$this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_INFOEXTRA, $params);
    }
    
    public function deleteInfoExtra($rows) {
        $params = array(
            ':CDINFOEXTRA'          => $rows[0]['CDINFOEXTRA'],
            ':DSINFOEXTRA'          => $rows[0]['DSINFOEXTRA'],
            ':DSOBSINFOEXTRA'       => $rows[0]['DSOBSINFOEXTRA'],
            ':NRORG'                => $rows[0]['NRORG']
        );
 		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_INFOEXTRA, $params);
    }
    
    public function exportTXTINFO() {
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TXTINFO);
	}

	/* Salva Cadastramento Automatico
     * @param $row
     * @throws \Exception
     */
    public function salvaCadastramentoAutomatico($row){
        try {

            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $params = array(
             	":P_CDFILIAL"    => $row['CDFILIAL'],
             	":P_CDINFOEXTRA" => $row['CDINFOEXTRA'],
             	":P_TODOS"       => ($row['INTERVALISTA'] != "T") ? null : $row['INTERVALISTA'],
             	":P_LISTA"       => !empty($row['LISTA']) ? implode('_', $row['LISTA']) : null,
             	":P_PRODINI"     => $row['CDARVPRODI'],
             	":P_PRODFIN"     => $row['CDARVPRODF'],
             	":P_CDTABEPREC"  => $row['CDTABEPREC']
     		);
     		
     		if($row['IDTABEPRECGER'] == "%S%" || $row['IDTABEPRECGER'] == "S") {
     		    $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_CADAUTOMATICO_PRODUTO_GERAL, $params);
     		} else {
     		    $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_CADAUTOMATICO_PRODUTO, $params);
     		}
     		
            $connection->commit();

        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
    
    public function exportArquivoNutricional(){
        $query = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_ARQUIVO_NUTRI);
        
        return $query;
    }

}
